==> eg_particle_interactions-v0.8.1-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/emitter/random_distribution/UnderwaterBubbleEmitter.java <==
package games.enchanted.eg_particle_interactions.common.particle.emitter.random_distribution;

import games.enchanted.eg_particle_interactions.common.particle.ModParticleTypes;
import games.enchanted.eg_particle_interactions.common.particle.option.RandomDistributionEmitterOptions;
import net.minecraft.class_2394;
import net.minecraft.class_4002;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class UnderwaterBubbleEmitter extends AbstractRandomDistributionEmitter {
    protected UnderwaterBubbleEmitter(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, RandomDistributionEmitterOptions emitterOptions) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, emitterOptions);
    }

    @Override
    protected class_2394 getParticleToEmit(class_638 level, double x, double y, double z) {
        return ModParticleTypes.UNDERWATER_RISING_BUBBLE_SMALL;
    }

    public static class Provider implements class_707<RandomDistributionEmitterOptions> {
        public Provider(class_4002 spriteSet) {}

        @Nullable
        @Override
        public class_703 createParticle(@NotNull RandomDistributionEmitterOptions emitterOptions, @NotNull class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed) {
            return new UnderwaterBubbleEmitter(level, x, y, z, xSpeed, ySpeed, zSpeed, emitterOptions);
        }
    }
}

==> eg_particle_interactions-v0.8.2-fabric-mc1.21.9-sources.jar: games/enchanted/eg_particle_interactions/common/particle/emitter/random_distribution/UnderwaterBubbleEmitter.java <==
package games.enchanted.eg_particle_interactions.common.particle.emitter.random_distribution;

import games.enchanted.eg_particle_interactions.common.particle.ModParticleTypes;
import games.enchanted.eg_particle_interactions.common.particle.option.RandomDistributionEmitterOptions;
import net.minecraft.class_2394;
import net.minecraft.class_4002;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class UnderwaterBubbleEmitter extends AbstractRandomDistributionEmitter {
    protected UnderwaterBubbleEmitter(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, RandomDistributionEmitterOptions emitterOptions) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, emitterOptions);
    }

    @Override
    protected class_2394 getParticleToEmit(class_638 level, double x, double y, double z) {
        return ModParticleTypes.UNDERWATER_RISING_BUBBLE_SMALL;
    }

    public static class Provider implements class_707<RandomDistributionEmitterOptions> {
        public Provider(class_4002 spriteSet) {}

        @Override
        public @Nullable class_703 createParticle(
            RandomDistributionEmitterOptions emitterOptions,
            class_638 level,
            double x,
            double y,
            double z,
            double xSpeed,
            double ySpeed,
            double zSpeed
            //? if minecraft: > 1.21.8 {
            , class_5819 random
            //?}
        ) {
            return new UnderwaterBubbleEmitter(level, x, y, z, xSpeed, ySpeed, zSpeed, emitterOptions);
        }
    }
}
